@@ -24,5 +24,5 @@ class MyWatch(Watch):
         self.trigger_haptics(1.0, 20)
         print('back button')
 
-watch = MyWatch('fvaf')
+watch = MyWatch()
 watch.start()
